@@ -182,7 +182,7 @@ class Propagate(object):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of assignment at {0}", self.loc,
+        with new_error_context("typing of assignment at {loc}",
                                loc=self.loc):
             typeinfer.copy_type(self.src, self.dst, loc=self.loc)
             # If `dst` is refined, notify us
@@ -203,7 +203,7 @@ class ArgConstraint(object):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of argument at {0}", self.loc):
+        with new_error_context("typing of argument at {loc}", loc=self.loc):
             typevars = typeinfer.typevars
             src = typevars[self.src]
             if not src.defined:
@@ -225,7 +225,7 @@ class BuildTupleConstraint(object):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of tuple at {0}", self.loc):
+        with new_error_context("typing of tuple at {loc}", loc=self.loc):
             typevars = typeinfer.typevars
             tsets = [typevars[i.name].get() for i in self.items]
             for vals in itertools.product(*tsets):
@@ -246,8 +246,9 @@ class _BuildContainerConstraint(object):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of {0} at {1}",
-                               self.container_type, self.loc):
+        with new_error_context("typing of {container_type} at {loc}",
+                               container_type=self.container_type,
+                               loc=self.loc):
             typevars = typeinfer.typevars
             tsets = [typevars[i.name].get() for i in self.items]
             if not tsets:
@@ -271,8 +272,8 @@ class BuildListConstraint(_BuildContainerConstraint):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of {0} at {1}",
-                               types.List, self.loc):
+        with new_error_context("typing of {container_type} at {loc}",
+                               container_type=types.List, loc=self.loc):
             typevars = typeinfer.typevars
             tsets = [typevars[i.name].get() for i in self.items]
             if not tsets:
@@ -313,7 +314,7 @@ class BuildMapConstraint(object):
 
     def __call__(self, typeinfer):
 
-        with new_error_context("typing of dict at {0}", self.loc):
+        with new_error_context("typing of dict at {loc}", loc=self.loc):
             typevars = typeinfer.typevars
 
             # figure out what sort of dict is being dealt with
@@ -379,7 +380,8 @@ class ExhaustIterConstraint(object):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of exhaust iter at {0}", self.loc):
+        with new_error_context("typing of exhaust iter at {loc}",
+                               loc=self.loc):
             typevars = typeinfer.typevars
             for tp in typevars[self.iterator.name].get():
                 # unpack optional
@@ -411,7 +413,8 @@ class PairFirstConstraint(object):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of pair-first at {0}", self.loc):
+        with new_error_context("typing of pair-first at {loc}",
+                               loc=self.loc):
             typevars = typeinfer.typevars
             for tp in typevars[self.pair.name].get():
                 if not isinstance(tp, types.Pair):
@@ -429,7 +432,8 @@ class PairSecondConstraint(object):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of pair-second at {0}", self.loc):
+        with new_error_context("typing of pair-second at {loc}",
+                               loc=self.loc):
             typevars = typeinfer.typevars
             for tp in typevars[self.pair.name].get():
                 if not isinstance(tp, types.Pair):
@@ -453,7 +457,8 @@ class StaticGetItemConstraint(object):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of static-get-item at {0}", self.loc):
+        with new_error_context("typing of static-get-item at {loc}",
+                               loc=self.loc):
             typevars = typeinfer.typevars
             for ty in typevars[self.value.name].get():
                 sig = typeinfer.context.resolve_static_getitem(
@@ -482,7 +487,8 @@ class TypedGetItemConstraint(object):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of typed-get-item at {0}", self.loc):
+        with new_error_context("typing of typed-get-item at {loc}",
+                               loc=self.loc):
             typevars = typeinfer.typevars
             idx_ty = typevars[self.index.name].get()
             ty = typevars[self.value.name].get()
@@ -556,13 +562,13 @@ class CallConstraint(object):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        msg = "typing of call at {0}\n".format(self.loc)
-        with new_error_context(msg):
+        with new_error_context("typing of call at {loc}", loc=self.loc):
             typevars = typeinfer.typevars
             with new_error_context(
-                    "resolving caller type: {}".format(self.func)):
+                    "resolving caller type: {func}", func=self.func):
                 fnty = typevars[self.func].getone()
-            with new_error_context("resolving callee type: {0}", fnty):
+            with new_error_context("resolving callee type: {fnty}",
+                                   fnty=fnty):
                 self.resolve(typeinfer, typevars, fnty)
 
     def resolve(self, typeinfer, typevars, fnty):
@@ -685,7 +691,8 @@ class CallConstraint(object):
 
 class IntrinsicCallConstraint(CallConstraint):
     def __call__(self, typeinfer):
-        with new_error_context("typing of intrinsic-call at {0}", self.loc):
+        with new_error_context("typing of intrinsic-call at {loc}",
+                               loc=self.loc):
             fnty = self.func
             if fnty in utils.OPERATORS_TO_BUILTINS:
                 fnty = typeinfer.resolve_value_type(None, fnty)
@@ -701,7 +708,8 @@ class GetAttrConstraint(object):
         self.inst = inst
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of get attribute at {0}", self.loc):
+        with new_error_context("typing of get attribute at {loc}",
+                               loc=self.loc):
             typevars = typeinfer.typevars
             valtys = typevars[self.value.name].get()
             for ty in valtys:
@@ -762,7 +770,7 @@ class SetItemConstraint(SetItemRefinement):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of setitem at {0}", self.loc):
+        with new_error_context("typing of setitem at {loc}", loc=self.loc):
             typevars = typeinfer.typevars
             if not all(typevars[var.name].defined
                        for var in (self.target, self.index, self.value)):
@@ -792,7 +800,8 @@ class StaticSetItemConstraint(SetItemRefinement):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of staticsetitem at {0}", self.loc):
+        with new_error_context("typing of staticsetitem at {loc}",
+                               loc=self.loc):
             typevars = typeinfer.typevars
             if not all(typevars[var.name].defined
                        for var in (self.target, self.index_var, self.value)):
@@ -822,7 +831,7 @@ class DelItemConstraint(object):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of delitem at {0}", self.loc):
+        with new_error_context("typing of delitem at {loc}", loc=self.loc):
             typevars = typeinfer.typevars
             if not all(typevars[var.name].defined
                        for var in (self.target, self.index)):
@@ -848,8 +857,8 @@ class SetAttrConstraint(object):
         self.loc = loc
 
     def __call__(self, typeinfer):
-        with new_error_context("typing of set attribute {0!r} at {1}",
-                               self.attr, self.loc):
+        with new_error_context("typing of set attribute {attr!r} at {loc}",
+                               attr=self.attr, loc=self.loc):
             typevars = typeinfer.typevars
             if not all(typevars[var.name].defined
                        for var in (self.target, self.value)):
